Learn R Programming

spANOVA (version 0.99.4)

contr.tuk: Tukey's contrast matrix

Description

Compute Tukey's contrast matrix

Usage

contr.tuk(x)

Value

The matrix of contrasts with treatments in row names is returned

Arguments

x

a vector of means.

Details

Computes the matrix of contrasts for comparisons of mean levels.

Examples

Run this code
x <- c(10, 5, 8, 4, 12, 18)
contr.tuk(x)

Run the code above in your browser using DataLab