Learn R Programming

spANOVA (version 0.99.3)

spANOVAapp: Shiny app for spANOVA

Description

Shiny app for analysis of variance with spatially correlated errors

Usage

spANOVAapp(external = TRUE)

Arguments

external

logical. If true, the system's default web browser will be launched automatically after the app is started.

Examples

Run this code
# NOT RUN {
spANOVAapp(external = TRUE)
# }

Run the code above in your browser using DataLab