powered by
Compute Tukey's contrast matrix
contr.tuk(x)
The matrix of contrasts with treatments in row names is returned
a vector of means.
Computes the matrix of contrasts for comparisons of mean levels.
x <- c(10, 5, 8, 4, 12, 18) contr.tuk(x)
Run the code above in your browser using DataLab