powered by
Compute Tukey's contrast matrix
contr.tuk(x)
a vector of means.
The matrix of contrasts with treatments in row names is returned
Computes the matrix of contrasts for comparisons of mean levels.
# NOT RUN { x <- c(10, 5, 8, 4, 12, 18) contr.tuk(x) # }
Run the code above in your browser using DataLab