powered by
Shiny app for analysis of variance with spatially correlated errors
spANOVAapp(external = TRUE)
logical. If true, the system's default web browser will be launched automatically after the app is started.
# NOT RUN { spANOVAapp(external = TRUE) # }
Run the code above in your browser using DataLab